# Security Policy

## Supported Versions

Always update to the latest version of OctoPrint to keep up with security patches.

## Reporting a Vulnerability

Email to security@octoprint.org. 

For the sake of the userbase of OctoPrint please always disclose responsibly and with a 90+ day window.
